"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.testCompositionRegistration = exports.TestComposition = void 0;
var tslib_1 = require("tslib");
var react_1 = tslib_1.__importDefault(require("react"));
var __1 = require("..");
var testComponents_1 = require("./testComponents");
var enzyme_1 = require("enzyme");
var enzyme_adapter_react_16_1 = tslib_1.__importDefault(require("enzyme-adapter-react-16"));
var createRegisterableComposition = __1.getRegistrationCreators().createRegisterableComposition;
enzyme_1.configure({ adapter: new enzyme_adapter_react_16_1.default() });
exports.TestComposition = function (props) { return (react_1.default.createElement("div", null,
    react_1.default.createElement("div", null, props.main),
    react_1.default.createElement("div", null, props.sidebar))); };
exports.testCompositionRegistration = createRegisterableComposition()('test-composition', function (contentAreas) { return react_1.default.createElement(exports.TestComposition, { main: contentAreas.main, sidebar: contentAreas.sidebar }); }, function (contentArea, _a) {
    var _b = _a.contentAreaRatio, contentAreaRatio = _b === void 0 ? 1 : _b;
    if (contentArea === 'main') {
        return { contentAreaRatio: 0.66 * contentAreaRatio };
    }
    return { contentAreaRatio: 0.32 * contentAreaRatio };
});
it('can pass props to all contained components', function () {
    var layout = __1.LayoutRegistration()
        .registerComponents(function (registrar) {
        return registrar
            .registerComponent(testComponents_1.testComponentRegistration)
            .registerComponent(testComponents_1.testComponent2Registration);
    })
        .registerCompositions(function (registrar) {
        return registrar.registerComposition(exports.testCompositionRegistration);
    });
    var renderers = layout.createRenderers({ services: {} });
    var wrapper = enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.component({
                    type: 'test',
                    props: {},
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(testComponents_1.TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 });
    expect(wrapper.find(testComponents_1.TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
it('nested compositions pass additional props to composition', function () {
    var layout = __1.LayoutRegistration()
        .registerComponents(function (registrar) {
        return registrar
            .registerComponent(testComponents_1.testComponentRegistration)
            .registerComponent(testComponents_1.testComponent2Registration);
    })
        .registerCompositions(function (registrar) {
        return registrar.registerComposition(exports.testCompositionRegistration);
    });
    var renderers = layout.createRenderers({ services: {} });
    var wrapper = enzyme_1.mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.nestedComposition({
                    type: 'test-composition',
                    props: {},
                    contentAreas: {
                        main: [
                            layout.component({
                                type: 'test',
                                props: {},
                            }),
                        ],
                        sidebar: [],
                    },
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(testComponents_1.TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 * 0.66 });
    expect(wrapper.find(testComponents_1.TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
//# sourceMappingURL=compositions.test.js.map