import React from 'react';
import { getRegistrationCreators, LayoutRegistration } from '..';
import { testComponentRegistration, testComponent2Registration, TestComponent, TestComponent2, } from './testComponents';
import { mount, configure } from 'enzyme';
import Adapter from 'enzyme-adapter-react-16';
var createRegisterableComposition = getRegistrationCreators().createRegisterableComposition;
configure({ adapter: new Adapter() });
export var TestComposition = function (props) { return (React.createElement("div", null,
    React.createElement("div", null, props.main),
    React.createElement("div", null, props.sidebar))); };
export var testCompositionRegistration = createRegisterableComposition()('test-composition', function (contentAreas) { return React.createElement(TestComposition, { main: contentAreas.main, sidebar: contentAreas.sidebar }); }, function (contentArea, _a) {
    var _b = _a.contentAreaRatio, contentAreaRatio = _b === void 0 ? 1 : _b;
    if (contentArea === 'main') {
        return { contentAreaRatio: 0.66 * contentAreaRatio };
    }
    return { contentAreaRatio: 0.32 * contentAreaRatio };
});
it('can pass props to all contained components', function () {
    var layout = LayoutRegistration()
        .registerComponents(function (registrar) {
        return registrar
            .registerComponent(testComponentRegistration)
            .registerComponent(testComponent2Registration);
    })
        .registerCompositions(function (registrar) {
        return registrar.registerComposition(testCompositionRegistration);
    });
    var renderers = layout.createRenderers({ services: {} });
    var wrapper = mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.component({
                    type: 'test',
                    props: {},
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 });
    expect(wrapper.find(TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
it('nested compositions pass additional props to composition', function () {
    var layout = LayoutRegistration()
        .registerComponents(function (registrar) {
        return registrar
            .registerComponent(testComponentRegistration)
            .registerComponent(testComponent2Registration);
    })
        .registerCompositions(function (registrar) {
        return registrar.registerComposition(testCompositionRegistration);
    });
    var renderers = layout.createRenderers({ services: {} });
    var wrapper = mount(renderers.renderCompositions(layout.composition({
        type: 'test-composition',
        props: {},
        contentAreas: {
            main: [
                layout.nestedComposition({
                    type: 'test-composition',
                    props: {},
                    contentAreas: {
                        main: [
                            layout.component({
                                type: 'test',
                                props: {},
                            }),
                        ],
                        sidebar: [],
                    },
                }),
            ],
            sidebar: [
                layout.component({
                    type: 'test2',
                    props: {},
                }),
            ],
        },
    })));
    expect(wrapper.find(TestComponent).props()).toMatchObject({ contentAreaRatio: 0.66 * 0.66 });
    expect(wrapper.find(TestComponent2).props()).toMatchObject({ contentAreaRatio: 0.32 });
});
//# sourceMappingURL=compositions.test.js.map