import { __assign, __rest } from "tslib";
import React from 'react';
import { ComponentsRenderer } from './components-renderer';
export var CompositionRenderer = function (_a) {
    var services = _a.services, layoutApi = _a.layoutApi, componentRenderPath = _a.componentRenderPath, composition = _a.composition, compositionMiddleware = _a.compositionMiddleware, componentRegistrations = _a.componentRegistrations, componentMiddleware = _a.componentMiddleware, compositionRegistrations = _a.compositionRegistrations, additionalComponentProps = _a.additionalComponentProps, log = _a.log;
    /**
     * The ContentAreaRenderer componentRenderPaths need to append `/[contentArea key]'
     * key as this logic is duped outside of react for the ssr
     */
    log.debug({
        componentRenderPath: componentRenderPath,
        type: composition.type,
    }, 'Rendering composition');
    var contentAreas = composition.contentAreas, compositionProps = composition.props, middlewareProps = __rest(composition, ["contentAreas", "props"]);
    var componentServices = {
        services: services,
        layout: layoutApi,
    };
    var compositionRegistration = compositionRegistrations.get(composition.type);
    if (!compositionRegistration) {
        return null;
    }
    // A middleware may call next with props, we should use them
    function render(middlewareCompositionProps) {
        var compositionRenderProps = __assign(__assign({}, additionalComponentProps), (middlewareCompositionProps || compositionProps));
        var contentAreas = Object.keys(composition.contentAreas).reduce(function (acc, contentAreaName) {
            var componentsRenderPath = componentRenderPath + "/" + contentAreaName;
            log.debug({
                componentsRenderPath: componentsRenderPath,
                components: composition.contentAreas[contentAreaName].map(function (component) { return ({
                    type: component.type,
                }); }),
            }, 'Rendering content area');
            var additionalProps = (compositionRegistration === null || compositionRegistration === void 0 ? void 0 : compositionRegistration.componentProps) ? compositionRegistration === null || compositionRegistration === void 0 ? void 0 : compositionRegistration.componentProps(contentAreaName, compositionRenderProps) : {};
            acc[contentAreaName] = (React.createElement(ComponentsRenderer, { componentMiddleware: componentMiddleware, componentRegistrations: componentRegistrations, componentRenderPath: componentsRenderPath, components: composition.contentAreas[contentAreaName], layoutApi: layoutApi, services: services, additionalComponentProps: additionalProps }));
            return acc;
        }, {});
        var rendered = compositionRegistration.render(contentAreas, compositionRenderProps, services) || null;
        return rendered;
    }
    var middlewareRender = compositionMiddleware(composition.props, middlewareProps, componentServices, render) || null;
    return middlewareRender;
};
CompositionRenderer.displayName = 'CompositionRenderer';
//# sourceMappingURL=composition-renderer.js.map